@@ -10,6 +10,24 @@ from aiohttp.web import Application, BaseRequest, StreamResponse
 AiohttpClient = Callable[[Union[Application, BaseTestServer]], Awaitable[TestClient]]
 
 
+LEGACY_MODE = DeprecationWarning(
+    "The 'asyncio_mode' is 'legacy', switching to 'auto' for the sake of "
+    "pytest-aiohttp backward compatibility. "
+    "Please explicitly use 'asyncio_mode=strict' or 'asyncio_mode=auto' "
+    "in pytest configuration file."
+)
+
+
+@pytest.mark.tryfirst
+def pytest_configure(config) -> None:
+    val = config.getoption("asyncio_mode")
+    if val is None:
+        val = config.getini("asyncio_mode")
+    if val == "legacy":
+        config.option.asyncio_mode = "auto"
+        config.issue_config_time_warning(LEGACY_MODE, stacklevel=2)
+
+
 @pytest.fixture
 def loop(event_loop: asyncio.AbstractEventLoop) -> asyncio.AbstractEventLoop:
     warnings.warn(
@@ -17,7 +35,7 @@ def loop(event_loop: asyncio.AbstractEventLoop) -> asyncio.AbstractEventLoop:
         "please use 'event_loop' instead",
         DeprecationWarning,
     )
-    return loop
+    return event_loop
 
 
 @pytest.fixture
@@ -27,7 +45,7 @@ def proactor_loop(event_loop: asyncio.AbstractEventLoop) -> asyncio.AbstractEven
         "please use 'event_loop' instead",
         DeprecationWarning,
     )
-    return loop
+    return event_loop
 
 
 @pytest.fixture
